busy

package
v0.0.0-...-c12a0b3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 27, 2017 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package busy contains a simple example utilizing go routines

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Basic

func Basic(writers, readers int)

Basic shows a very basic usage of channels

func MapRace

func MapRace(N int)

MapRace purposefully forces race conditions, to demonstrate the functionality of the 'go test -race' race detector

Types

This section is empty.

Jump to