say

package
v0.0.0-...-c12a0b3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 27, 2017 License: MIT Imports: 2 Imported by: 1

Documentation

Overview

Package say is an example go package with no real functionality

It covers the basics of:

  • interfaces
  • type syntax

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type I

type I int64

I typedef for int64 (64 bit int). Typedef'd parameters can add any sort of functionality

func NewI

func NewI(i int64) *I

NewI returns a instantiated I from the passed value i

func (*I) CanConvert

func (i *I) CanConvert(iface interface{}) bool

Parse is an exposed pointer receiver. It takes any single argument and attempt to set i to the value. interface{} can be seen as 'anything' variable, but is a bit more nuanced.

func (I) CountDown

func (i I) CountDown()

CountDown prints some interesting factoids

func (*I) Say

func (i *I) Say() (r string)

Say conforms to the Sayer interface. Say is a pointer receiver on I.

type Sayer

type Sayer interface {
	Say() string
}

Sayer is an exported interface declaration. Title case declarations are exported.

Jump to