package
Version:
v0.0.0-...-c12a0b3
Opens a new window with list of versions in this module.
Published: May 27, 2017
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package busy contains a simple example utilizing go routines
func Basic(writers, readers int)
Basic shows a very basic usage of channels
MapRace purposefully forces race conditions, to demonstrate the
functionality of the 'go test -race' race detector
Source Files
¶
Click to show internal directories.
Click to hide internal directories.