Documentation
¶
Overview ¶
Package say is an example go package with no real functionality
It covers the basics of:
- interfaces
- type syntax
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type I ¶
type I int64
I typedef for int64 (64 bit int). Typedef'd parameters can add any sort of functionality
func (*I) CanConvert ¶
Parse is an exposed pointer receiver. It takes any single argument and attempt to set i to the value. interface{} can be seen as 'anything' variable, but is a bit more nuanced.
Click to show internal directories.
Click to hide internal directories.